#[non_exhaustive]#[repr(u32)]pub enum TimerfdClockId {
Realtime = 0,
Monotonic = 1,
Boottime = 7,
RealtimeAlarm = 8,
BoottimeAlarm = 9,
}Expand description
CLOCK_* constants for use with timerfd_create.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Realtime = 0
CLOCK_REALTIME—A clock that tells the “real” time.
This is a clock that tells the amount of time elapsed since the Unix epoch, 1970-01-01T00:00:00Z. The clock is externally settable, so it is not monotonic. Successive reads may see decreasing times, so it isn’t reliable for measuring durations.
Monotonic = 1
CLOCK_MONOTONIC—A clock that tells an abstract time.
Unlike Realtime, this clock is not based on a fixed known epoch, so
individual times aren’t meaningful. However, since it isn’t settable,
it is reliable for measuring durations.
This clock does not advance while the system is suspended; see
Boottime for a clock that does.
Boottime = 7
CLOCK_BOOTTIME—Like Monotonic, but advances while suspended.
This clock is similar to Monotonic, but does advance while the system
is suspended.
RealtimeAlarm = 8
CLOCK_REALTIME_ALARM—Like Realtime, but wakes a suspended system.
This clock is like Realtime, but can wake up a suspended system.
Use of this clock requires the CAP_WAKE_ALARM Linux capability.
BoottimeAlarm = 9
CLOCK_BOOTTIME_ALARM—Like Boottime, but wakes a suspended system.
This clock is like Boottime, but can wake up a suspended system.
Use of this clock requires the CAP_WAKE_ALARM Linux capability.